@@ -1,7 +1,7 @@
 extern crate reed_solomon_32;
 
-use reed_solomon_32::Encoder;
-use reed_solomon_32::Decoder;
+use reed_solomon_32::encode;
+use reed_solomon_32::correct;
 
 fn main() {
     let data = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9];
@@ -9,12 +9,8 @@ fn main() {
     // Length of error correction code
     let ecc_len = 8;
 
-    // Create encoder and decoder with 
-    let enc = Encoder::new(ecc_len);
-    let dec = Decoder::new(ecc_len);
-
     // Encode data
-    let encoded = enc.encode(&data).unwrap();
+    let encoded = encode(&data, ecc_len).unwrap();
 
     // Simulate some transmission errors
     let mut corrupted = *encoded;
@@ -24,7 +20,7 @@ fn main() {
 
     // Try to recover data
     let known_erasures = [0];
-    let recovered = dec.correct(&mut corrupted, Some(&known_erasures)).unwrap();
+    let recovered = correct(&mut corrupted, ecc_len, Some(&known_erasures)).unwrap();
 
     let orig_str = std::str::from_utf8(&data).unwrap();
     let recv_str = std::str::from_utf8(recovered.data()).unwrap();
