@@ -1,20 +1,16 @@
 extern crate reed_solomon_32;
 
-use reed_solomon_32::Encoder;
-use reed_solomon_32::Decoder;
+use reed_solomon_32::encode;
+use reed_solomon_32::correct;
 
-const ECC_LEN: usize = 8;
+const ECC_LEN: u8 = 8;
 
 #[test]
 fn helloworld() {
     let data = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9];
 
-    // Create encoder and decoder
-    let enc = Encoder::new(ECC_LEN);
-    let dec = Decoder::new(ECC_LEN);
-
     // Encode data
-    let encoded = enc.encode(&data[..]).unwrap();
+    let encoded = encode(&data[..], ECC_LEN).unwrap();
 
     // Simulate some transmission errors
     let mut corrupted = *encoded;
@@ -23,7 +19,7 @@ fn helloworld() {
     }
 
     // Try to recover data
-    let recovered = dec.correct(&mut corrupted, None).unwrap();
+    let recovered = correct(&mut corrupted, ECC_LEN, None).unwrap();
 
     assert_eq!(data, recovered.data());
 }
@@ -32,12 +28,8 @@ fn helloworld() {
 fn with_erasures() {
     let data = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9];
 
-    // Create encoder and decoder
-    let enc = Encoder::new(ECC_LEN);
-    let dec = Decoder::new(ECC_LEN);
-
     // Encode data
-    let encoded = enc.encode(&data[..]).unwrap();
+    let encoded = encode(&data[..], ECC_LEN).unwrap();
 
     // Simulate some transmission errors
     let mut corrupted = *encoded;
@@ -47,7 +39,7 @@ fn with_erasures() {
 
     // Try to recover data
     let known_erasures = [0, 1, 2];
-    let recovered = dec.correct(&mut corrupted, Some(&known_erasures)).unwrap();
+    let recovered = correct(&mut corrupted, ECC_LEN, Some(&known_erasures)).unwrap();
 
     assert_eq!(data, recovered.data());
 }
